@@ -536,7 +536,7 @@ class File(object):
     def jlgs(cls, filenames, handle_errors=True):
         filenames = File.fsorter(filenames)
         for fname in filenames:
-            yield File.jlg(fname, handle_errors)
+            yield from File.jlg(fname, handle_errors)
     
 
     @classmethod
@@ -1043,11 +1043,13 @@ class File(object):
             File.copy(src_dict[key], dest_dict[key], overwrite=overwrite)
     
     @classmethod
-    def get_local(cls, filenames, directory='/content/data', ovewrite=False):
+    def get_local(cls, filenames, directory=None, overwrite=False):
+        if not directory:
+            directory = File.join(curdir(), 'data')
         filenames = File.fsorter(filenames)
         lpaths = []
         for fpath in filenames:
-            lpath = File.bcopy(fpath, directory, overwrite=ovewrite)
+            lpath = File.bcopy(fpath, directory, overwrite=overwrite)
             lpaths.append(lpath)
         return lpaths
     
